@@ -183,12 +183,12 @@
   
   # 
   if(!resultType %in% c("trackdata")){
-    if(consistentOutputType == F){
+    if(consistentOutputType == FALSE){
       if(verbose){
         cat(paste0("INFO: resetting 'consistentOutputType' back to TRUE as setting ",
                    "it to FALSE is only allowed when resultType is set to 'trackdata'\n"))
       }
-      consistentOutputType = T
+      consistentOutputType = TRUE
     }
   }
   
@@ -215,6 +215,7 @@
     trackDef[[1]]$name = "CUSTOM_FUNCTION"
     trackDef[[1]]$columnName = "CUSTOM_FUNCTION"
     trackDef[[1]]$fileExtension = "CUSTOM_FUNCTION"
+    trackCache = list()
   }else{
     if(is.null(onTheFlyFunctionName)){
       trackDefFound = sapply(DBconfig$ssffTrackDefinitions, 
@@ -247,12 +248,12 @@
                                          sep = ":", 
                                          col.names = c("session", "bundle"), 
                                          colClasses = c("character", "character"), 
-                                         stringsAsFactors = F)
+                                         stringsAsFactors = FALSE)
   }else{
     uniqSessionBndls = dplyr::distinct(as.data.frame(seglist), .data$bundle, .data$session)
   }
   DBI::dbExecute(emuDBhandle$connection,"CREATE TEMP TABLE uniq_session_bndls_tmp (session TEXT,bundle TEXT)")
-  DBI::dbWriteTable(emuDBhandle$connection, "uniq_session_bndls_tmp", uniqSessionBndls, append = T)
+  DBI::dbWriteTable(emuDBhandle$connection, "uniq_session_bndls_tmp", uniqSessionBndls, append = TRUE)
   sesBndls = DBI::dbGetQuery(emuDBhandle$connection, paste0("SELECT ",
                                                             " bundle.db_uuid, ",
                                                             " bundle.session, ",
@@ -274,8 +275,8 @@
                    "audio files! Here is a list of all refered to bundles incl. their sampling rate: \n"), 
             paste(utils::capture.output(print(sesBndls %>% 
                                                 dplyr::rename(
-                                                  bundle = .data$name,
-                                                  media_file = .data$annotates
+                                                  bundle = "name",
+                                                  media_file = "annotates"
                                                 ))), 
                   collapse = "\n"))
   }
@@ -361,7 +362,14 @@
         }
         
       } else { # if precalculated track read in file
-        curDObj <- wrassp::read.AsspDataObj(fpath)
+        if(file.exists(fpath)){
+          # if file doesn't exist this causes the R session to crash
+          # this didn't used to be the case? Further wrassp debugging 
+          # needed...
+          curDObj <- wrassp::read.AsspDataObj(fpath)
+        } else {
+          stop("trying wrassp::read.AsspDataObj() on a file path that doesn't exist: ", fpath)
+        }
       }
       
       # set origFreq 
@@ -420,7 +428,7 @@
                                          trackDef[[1]]$columnName, 
                                          sep = "")))
       
-      if(is.null(tmpData) && class(curDObj) == "AsspDataObj"){
+      if(is.null(tmpData) && inherits(curDObj, "AsspDataObj")){
         stop("Couldn't extract column with name: ",
              "'", trackDef[[1]]$columnName, "' from AsspDataObj ",
              "that was generated by a wrassp::read.AsspDataObj() ",
@@ -510,10 +518,20 @@
       prevUtt = curUtt
     } else {
       # use custom function
-      customFunctionRes = onTheFlyFunction(file.path(emuDBhandle$basePath, 
-                                                     paste0(splUtt[1], session.suffix), 
-                                                     paste0(splUtt[2], bundle.dir.suffix), 
-                                                     paste0(splUtt[2], ".", DBconfig$mediafileExtension)))
+      mediaPath <- file.path(emuDBhandle$basePath, 
+                             paste0(splUtt[1], session.suffix), 
+                             paste0(splUtt[2], bundle.dir.suffix), 
+                             paste0(splUtt[2], ".", DBconfig$mediafileExtension))
+      
+      if(is.null(trackCache[[mediaPath]])){
+        customFunctionRes = onTheFlyFunction(mediaPath)
+        trackCache[[mediaPath]] <- customFunctionRes
+      }
+      else
+      {
+        warning("Cached results were used")
+        customFunctionRes = trackCache[[mediaPath]]
+      }
       
       if(!"frame_time" %in% colnames(customFunctionRes)){
         stop("The function passed in to onTheFlyFunction didn't return a data.frame with a column called 'frame_time'!")  
@@ -527,7 +545,7 @@
       ftime[i,] <- c(min(customFunctionRes_filtered$frame_time), max(customFunctionRes_filtered$frame_time))
       
       # set data_list entry and timeStamp
-      data_list[[i]] = as.matrix(dplyr::select(customFunctionRes_filtered, -.data$frame_time))
+      data_list[[i]] = as.matrix(dplyr::select(customFunctionRes_filtered, -"frame_time"))
       timeStampRowNames_list[[i]] = customFunctionRes_filtered %>% dplyr::pull(.data$frame_time)
       
       # reset start index
